const char *trap_help_ifcspec = "Format of TRAP interface specifier (IFC_SPEC):\n"
   "==============================================\n"
   "\n"
   "TRAP interface specifier is an argument of `-i` option used by every NEMEA module. It specifies a configuration of module's TRAP interfaces (IFC), i.e. what kind of IFC to use and where to connect.\n"
   "\n"
   "Configurations of individual IFCs are separated by comma `,`, e.g. `<IFC 1>,<IFC 2>,...,<IFC N>`. Input IFCs must be specified first, output IFCs follow. The number of input and output IFCs depends on the specific module (you should be able to find it in the module's help or README).\n"
   "\n"
   "Parameters of each IFC are separated by colon `:`, e.g. `<type>:<par1>:<par2>:...:<parN>`. The first parameter is always one character specifying the type of the IFC to use, other parameters differ for individual types (see below).\n"
   "\n"
   "Example of startup of a module with 1 input and 1 output IFC:\n"
   "\n"
   "traffic_repeater -i t:example.org:1234,u:my_socket\n"
   "\n"
   "The example makes the repeater to use a TCP socket as its input IFC and connect it to 'example.org', port 1234; and to create an UNIX domain socket identified as 'my_socket' as its output IFC.\n"
   "\n"
   "Supported interface types:\n"
   "==========================\n"
   "\n"
   "TCP interface ('t')\n"
   "-------------------\n"
   "\n"
   "Communicates through a TCP socket. Output interface listens on a given port, input interface connects to it. There may be more than one input interfaces connected to one output interface, every input interface will get the same data.\n"
   "\n"
   "Parameters when used as INPUT interface:\n"
   "\n"
   "\n"
   "t:<hostname or ip>:<port>\n"
   "\n"
   "\n"
   "or\n"
   "\n"
   "\n"
   "t:<port>\n"
   "\n"
   "\n"
   "If you skip `<hostname or ip>:`, IFC assumes you want to use localhost as the hostname.\n"
   "\n"
   "Parameters when used as OUTPUT interface:\n"
   "\n"
   "\n"
   "<port>:<max_clients=>,<buffer_count=>,<buffer_size=>\n"
   "\n"
   "\n"
   "Maximum number of connected clients (max_clients=64 by default), buffer count and size (buffer_count=50,buffer_size=100000 by default) are optional parameters.\n"
   "\n"
   "TLS interface ('T')\n"
   "-------------------\n"
   "\n"
   "Communicates through a TCP socket after establishing encrypted connection. You have to provide certificate, key and CA chain file with trusted CAs. Otherwise same as in TCP: Output interface listens on a given port, input interface connects to it. There may be more than one input interfaces connected to one output interface, every input interface will get the same data.\n"
   "\n"
   "Parameters when used as INPUT interface:\n"
   "\n"
   "\n"
   "T:<hostname or ip>:<port>:<keyfile>:<certfile>:<CAfile>\n"
   "\n"
   "\n"
   "or\n"
   "\n"
   "\n"
   "T:<port>:<keyfile>:<certfile>:<CAfile>\n"
   "\n"
   "\n"
   "If you skip `<hostname or ip>:`, IFC assumes you want to use localhost as a hostname.\n"
   "\n"
   "Parameters when used as OUTPUT interface:\n"
   "\n"
   "<port>::<keyfile>:<certfile>:<CAfile>:<max_clients=>,<buffer_count=>,<buffer_size=>\n"
   "\n"
   "Interface uses the same optional parameters as TCP interface (max_clients, buffer_count and buffer_size). Optional parameters must be specified after mandatory parameters.\n"
   "\n"
   "Parameters keyfile, certfile, CAfile expect a path to apropriate files in PEM format.\n"
   "\n"
   "UNIX domain socket ('u')\n"
   "------------------------\n"
   "\n"
   "Communicates through a UNIX socket. Output interface creates a socket and listens, input interface connects to it. There may be more than one input interfaces connected to one output interface, every input interface will get the same data.\n"
   "\n"
   "Parameters when used as INPUT interface:\n"
   "\n"
   "<socket_name>\n"
   "\n"
   "Socket name can be any string usable as a file name.\n"
   "\n"
   "Parameters when used as OUTPUT interface:\n"
   "\n"
   "<socket_name>:<max_clients=>,<buffer_count=>,<buffer_size=>\n"
   "\n"
   "Socket name can be any string usable as a file name.\n"
   "Interface uses the same optional parameters as TCP interface (max_clients, buffer_count and buffer_size). Optional parameters must be specified after mandatory parameters.\n"
   "\n"
   "\n"
   "Blackhole interface ('b')\n"
   "-------------------------\n"
   "\n"
   "Can be used as OUTPUT interface only. Does nothing, everything sent to this interface is dropped. It has no parameters.\n"
   "\n"
   "\n"
   "File interface ('f')\n"
   "--------------------\n"
   "\n"
   "Input interface reads data from given files, output interface stores data to multiple files. Recommended file name extension for files with captured TRAP traffic is `.trapcap`. Tilde (`~`) can be used to specify home directory when specifying path, e.g. `~/nemea/data.trapcap`.\n"
   "\n"
   "Input interface:\n"
   "Files to be read by input interface can be specified with globbing.\n"
   "E.g. lets say, we have multiple data files captured on 18th of April 2016, with names like data.201604180900, data.201604181000.\n"
   "Following syntax can be used:\n"
   "\n"
   "<file_name> 	// e.g. data.201604180900 - reads data only from file \"data.201604180900\"\n"
   "<file_name*> 	// e.g. data.20160418* - reads data from all files in directory that were captured on 18th of April.\n"
   "\n"
   "Name of file (path to the file) must be specified.\n"
   "Input file interface can also read from /dev/stdin.\n"
   "\n"
   "Output interface:\n"
   "\n"
   "<file_name>:<mode>:<time=>:<size=>\n"
   "\n"
   "Name of file (path to the file) must be specified.\n"
   "\n"
   "Mode is optional. There are two types of mode: `a` - append, `w` - write (default).\n"
   "If the specified file exists, mode write overwrites it, mode append creates a new file with an integer suffix, e.g. `data.trapcap.00000` (or `data.trapcap.00001` if the former exists, and so on, it simply finds the first unused number).\n"
   "\n"
   "If parameter `time=` is set, the output interface will split captured data to individual files as often, as value of this parameter indicates.\n"
   "Output interface assumes the value of parameter `time=` is in minutes.\n"
   "If parameter `time=` is set, the output interface creates unique file name for each file according to current timestamp in format: filename.YYYYmmddHHMM\n"
   "Parameter `time=` is optional and is not set by default.\n"
   "\n"
   "If parameter `size=` is set, the output interface will split captured data to individual files after size of current file exceeds given threshold.\n"
   "Output interface assumes the value of parameter `size=` is in MB.\n"
   "If parameter `size=` is set, numeric suffix as added to original file name for each file in ascending order starting with 00000.\n"
   "Parameter `size=` is optional and is not set by default.\n"
   "\n"
   "If both `time=` and `size=` are specified, the data are split primarily by time, and only if a file of one time interval exceeds the size limit, it is further splitted. The index of size-splitted file is appended after the time, e.g. `data.trapcap.201604181000.00000`.\n"
   "\n"
   "Example:\n"
   "\n"
   "-i \"f:~/nemea/data.trapcap:w\"                  // stores all captured data to one file (overwrites current file if it exists)\n"
   "-i \"f:~/nemea/data.trapcap:w:time=30\"          // creates individual files each 30 minutes, e.g. \"data.trapcap.201604180930\", \"data.trapcap.201604181000\" etc.\n"
   "-i \"f:~/nemea/data.trapcap:w:size=100\"         // creates file \"data.trapcap\" and when its size reaches 100 MB, a new file named \"data.trapcap.00000\", then \"data.trapcap.00001\" etc.\n"
   "-i \"f:~/nemea/data.trapcap:w:time=30:size=100\" // creates set of files \"data.trapcap.201604180930\", \"data.trapcap.201604180930.00000\" etc. and after 30 minutes, \"data.trapcap.201604181000\"\n"
   "\n"
   "Output file interface and negotiation:\n"
   "Whenever new format of data is created, output interface creates new file with numeric suffix.\n"
   "Example: `-i \"f:~/nemea/data.trapcap:w\"` following sequence of files will be created if data format changes: data.trapcap, data.trapcap.00000, data.trapcap.00001 etc.\n"
   "\n"
   "When mode `a` is specified, the interface finds first non-existing file in which it writes data.\n"
   "Example: \n"
   "Assume we have already files \"data.trapcap\" and \"data.trapcap.00000\", the following command:\n"
   "\n"
   "-i \"f:~/nemea/data.trapcap:a\"\n"
   "\n"
   "checks for existing files and first captured data will be stored to file \"data.trapcap.00001\".\n"
   "\n"
   "Output file interface can also write data to /dev/stdout and /dev/null, however mode `w` must be specified.\n"
   "\n"
   "Common IFC parameters\n"
   "=====================\n"
   "\n"
   "The following parameters can be used with any type of IFC. There are parameters of libtrap IFC that are normally let default or set in source codes of a module. It is possible to override them by user via IFC_SPEC. The available parameters are:\n"
   "* timeout - time in microseconds that an IFC can block waiting for message send / receive\n"
   "   * possible values: number of microseconds or one of the special values:\n"
   "     * \"WAIT\" - block indefinitely\n"
   "     * \"NO_WAIT\" - don't block \n"
   "     * \"HALF_WAIT\" (output IFC only) - block only if some client (input IFC) is connected\n"
   "   * default: WAIT\n"
   "* buffer (OUTPUT only) - buffering of data and sending in larger bulks (increases throughput)\n"
   "   * possible values: on, off\n"
   "   * default: on\n"
   "* autoflush - normally data are not sent until the buffer is full. When autoflush is enabled, even non-full buffers are sent every X microseconds.\n"
   "   * possible values: off, number of microseconds\n"
   "   * default: 2000000 (2s)\n"
   "\n"
   "Example: `-i u:inputsocket:timeout=WAIT,u:outputsocket:timeout=500000:buffer=off:autoflush=off`\n"
   "\n"
   "\n"
   "More examples:\n"
   "==============\n"
   "\n"
   "my_module with 1 input interface and 2 output interfaces:\n"
   "\n"
   "./my_module -i \"t:localhost:12345,b:,t:23456:5\"\n"
   "\n"
   "The input interface will connect to localhost:12345 (TCP). The first output interface is unused (all data send there will be dropped), the second output interface will provide data on TCP port 23456, to which another module can connect its input interface.\n"
   "\n"
   "nfdump_reader module that reads nfdump file and drops records via Blackhole IFC type:\n"
   "\n"
   "./modules/nfreader/nfdump_reader -i b: ./file.nfdump\n"
   "\n";
